==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/OperationBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.OperationBody;
import io.ciera.tool.sql.ooaofooa.body.OperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.O_TFRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_TFRSetImpl;

import java.util.Arrays;
import java.util.List;


public class OperationBodySetImpl extends InstanceSet<OperationBodySet,OperationBody> implements OperationBodySet {

    // attributes
    @Override
    public void setTfr_ID( UniqueId ref_Tfr_ID ) throws XtumlException {
        for ( OperationBody operationbody : this ) operationbody.setTfr_ID( ref_Tfr_ID );
    }
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( OperationBody operationbody : this ) operationbody.setAction_ID( ref_Action_ID );
    }


    // selections
    @Override
    public O_TFRSet R696_specifies_processing_for_O_TFR() throws XtumlException {
        O_TFRSet o_tfrset = new O_TFRSetImpl();
        for ( OperationBody operationbody : this ) o_tfrset.add( operationbody.R696_specifies_processing_for_O_TFR() );
        return o_tfrset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( OperationBody operationbody : this ) bodyset.add( operationbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public OperationBody nullElement() {
        return OperationBodyImpl.EMPTY_OPERATIONBODY;
    }

    @Override
    public OperationBodySet emptySet() {
      return new OperationBodySetImpl();
    }

    @Override
    public OperationBodySet value() {
        return this;
    }

    @Override
    public List<OperationBody> elements() {
        return Arrays.asList(toArray(new OperationBody[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/OperationBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.OperationBody;
import io.ciera.tool.sql.ooaofooa.body.OperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.O_TFRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_TFRSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class OperationBodySetImpl extends InstanceSet<OperationBodySet,OperationBody> implements OperationBodySet {

    public OperationBodySetImpl() {
    }

    public OperationBodySetImpl(Comparator<? super OperationBody> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( OperationBody operationbody : this ) operationbody.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setTfr_ID( UniqueId ref_Tfr_ID ) throws XtumlException {
        for ( OperationBody operationbody : this ) operationbody.setTfr_ID( ref_Tfr_ID );
    }


    // selections
    @Override
    public O_TFRSet R696_specifies_processing_for_O_TFR() throws XtumlException {
        O_TFRSet o_tfrset = new O_TFRSetImpl();
        for ( OperationBody operationbody : this ) o_tfrset.add( operationbody.R696_specifies_processing_for_O_TFR() );
        return o_tfrset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( OperationBody operationbody : this ) bodyset.add( operationbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public OperationBody nullElement() {
        return OperationBodyImpl.EMPTY_OPERATIONBODY;
    }

    @Override
    public OperationBodySet emptySet() {
      return new OperationBodySetImpl();
    }

    @Override
    public OperationBodySet emptySet(Comparator<? super OperationBody> comp) {
      return new OperationBodySetImpl(comp);
    }

    @Override
    public OperationBodySet value() {
        return this;
    }

    @Override
    public List<OperationBody> elements() {
        return Arrays.asList(toArray(new OperationBody[0]));
    }

}
